package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````T)L$"#0```#8M@```````#0`(``'
M`"@`&P`:``8````T````-(`$"#2`!`C@````X`````4````$`````P```!0!
M```4@00(%($$"!,````3````!`````$````!``````````"`!`@`@`0('+(`
M`!RR```%`````!````$````<L@``'$(%"!Q"!0AP`@``U!(```8`````$```
M`@```#"R```P0@4(,$(%"/@```#X````!@````0````$````*`$``"B!!`@H
M@00((````"`````$````!````%'E=&0```````````````````````````8`
M```$````+VQI8B]L9"UL:6YU>"YS;RXR```$````$`````$```!'3E4`````
M``(````&````"````&$```!R````"@``````````````00````````!&````
M10``````````````6````#P````W````20````,```!6`````````#````!=
M````4P```&@```!J````90````0````K```````````````I````80```$0`
M````````;@```&(```!'````8P````@`````````4````'$````!````2P``
M```````>`````````&\`````````3P```&P``````````````&0````G````
M30```#@``````````````&T````'````/@```$,``````````````!(`````
M````/0``````````````(@`````````;````+P````L````Q````*````%(`
M`````````````%D```!.````.@```%P```!*````.0```#,`````````#```
M`````````````````%0```!K`````````$(```!;````0````#L````F````
M````````````````````````````````````````````````````````````
M`````````$P```````````````````````````````X`````````#P```!0`
M``!>````````````````````$P``````````````$0`````````8````````
M`````````````````%<`````````50````````!F```````````````0````
M````````````````&@`````````E````9P```",`````````+@```"0````-
M````'`````````!?````(``````````9````"0``````````````/P``````
M```R````'0```"T`````````<````%H`````````2`````8`````````````
M`&D````````````````````````````````````A```````````````7````
M`````#0`````````*@`````````````````````````6`````````!4`````
M````40`````````%````````````````````8````#4````"`````````!\`
M```L````-@```"4```!,````"`````@`````$!`$)4`$@*@1``&BAD&H0```
M`DLH1"DXHC)'B@0,B$P```!.````````````````````40```%,```!4````
M`````%4```!6`````````%<```!8````60````````!:````````````````
M````6P```%X``````````````%\```!A````8@```&0`````````9@```&D`
M````````:P```&P```!M````;P````````#(U;)Q6>CM[.;_,*+.WD<MH^#[
M2>K3[PZGW:-K+\6;MMO-XYZ'^9R!:PE#U@TZEPO%B060#13BGB'_Y`ZR`8MO
MQ+F<0&M_FGQ_J9R;;L7?']EQ6!R[XY)\U&34?*U+X\`R8MOMX:<""F:OS&9@
M%LE9>_!*:^)'Q@%#1=7L1^PS.GU!CL7"Y3\LMX"%9/+;TQWZH6Q@N8WQ#@``
M```````````````````U`P```````#0````2````L0`````````-````$@``
M`'(#````````,0```!(```!=`P```````#@````2````H0$````````O````
M$@```'H"````````*04``!(````1```````````````@````(```````````
M````(````&,#````````9P(``!(```"-`0````````T````2````$@0`````
M```_````$@```&X!````````#0```!(```"``0````````L````2````3@,`
M``````#&````$@```!X#````````\P```!(```#X`@```````*4````2````
M+`(```````#Q`P``$@```/T`````````70,``!(````<`@```````$T````2
M````C@,```````!8````$@```,H!````````:@$``!(```#V`P```````+(!
M```2````UP(```````![````$@`````#````````<````!(```"8`@``````
M`,\!```2````Z@$````````6````$@```*8!````````XP```!(````U`@``
M`````-4"```2````'`0````````_````$@```.@#````````.````!(````O
M`0````````T````2````J0,```````"2````$@```#0`````````B0```!(`
M``"Q`P```````#P````2````70$```````!<`0``$@```,@`````````W08`
M`!(```#6`P```````+\````2````H@,```````!&````$@```,\#````````
MS`,``!(```"'`P```````*\````2````5@,````````T````$@```-H$````
M````+@$``!(```!!`0```````($!```2````OP,````````,````$@```%P"
M````````&P,``!(```!%`P```````%4````2````ZP(```````!E````$@``
M`$X"````````T1,``!(```"5`P```````&\!```2````D0(```````!U`0``
M$@```*L!````````U@```!(```"<`P```````#0````2````@`,````````2
M`0``$@```.P`````````#0```!(```!"``````````L````2````Q@,`````
M```Z````$@```.`#````````E````!(```#7`````````#X````2````_@$`
M```````-````$@```(4"````````8````!(```!0`0```````)T````2````
M:P,```````";`0``$@```#T#````````\P```!(```#Q`@```````.4````2
M````'0$````````-````$@```$,"````````+@,``!(```!4`````````'0`
M```2````>0,```````!7````$@```-@!````````%@```!(```!C````````
M``T````2````[P,```````!4````$@```(\`````````#0```!(````P`P``
M`````/H````2````>`````````!>````$@````L!````````CP@``!(```"W
M`0``7)<$"%`````2````>P0``*#4!`@$````$0`/`%$%``!@UP0(N%H``!$`
M#P!;!0``0+\$"-X&```2``T`AP4``'RE!`BU`0``$@`-`'4$``!\U`0(````
M`!(`#@`*!```H$0%"`0````A`!@`300``+:A!`@-````$@`-`!,%``!PTP0(
M6@```!(`#0"@````+)D$"%`````2````_@0``&Q$!0@`````$``7```%``!L
M1`4(`````"``%P`)!```H$0%"`0````A`!@`:P0``&#3!`@%````$@`-`'H%
M``##H00(20(``!(`#0"8!```,:<$"%@````2``T`"`0``*!$!0@$````$0`8
M``,$``!"T`0(U`(``!(`#0#(!```S[T$"#T````2``T`XP0``'G'!`A[````
M$@`-`#P$``",1`4(`````!``\?](!```\%0%"``````0`/'_@@0``*G*!`@M
M!0``$@`-``\#``"DU`0(!````!$`#P`$!0``T)L$"``````2``T`I@0``-F@
M!`C=````$@`-`+P$``!.I`0(+@$``!(`#0#O!```B$0%"`0````1`!<`:@(`
M`!R9!`B,!P``$@```%X$```,I`0(0@```!(`#0`U!```C$0%"``````0`/'_
M3`4``(1$!0@$````$0`7`",%``!-R@0(7````!(`#0`+!0``5)P$"$8````2
M``T`/P4``![&!`A;`0``$@`-`*,"``"D1`4($P```!$`&`!H!0``#+X$"#0!
M```2``T`#04``+R6!`@`````$@`+``!L:6)P97)L+G-O+C4N,3``7U]G;6]N
M7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E
M<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA
M9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T
M<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R
M;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R
M7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O
M<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E
M<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R
M`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!0
M97)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!0
M97)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E
M<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U
M;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L
M7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F
M97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O
M+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I
M9FEC`&-L;W-E`&]P96XV-`!L<V5E:S8T`')E860`;&EB8RYS;RXV`%])3U]S
M=&1I;E]U<V5D`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W!R:6YT9@!S=')N
M8VUP`&-L;W-E9&ER`'-T<FYC<'D`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M
M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`&UE;6-P>0!O<&5N9&ER`%]?8W1Y<&5?8E]L;V,`9V5T=6ED`')E
M861L:6YK`&5X96-V<`!R96%D9&ER-C0`;65M;6]V90!A8V-E<W,`<W1R8VUP
M`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7WAS=&%T-C0`7U]L>'-T
M870V-`!L:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`'!A
M<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!?
M9G!?:'<`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'-I>F5?;&]A9%]M95\R`%]?9&%T
M85]S=&%R=`!X<U]I;FET`%]?;&EB8U]C<W5?:6YI=`!84U]);G1E<FYA;'-?
M4$%27T-,14%24U1!0TL`<&%R7W)M=&UP9&ER`&YA;65?;&]A9%]M95\R`'!A
M<E]M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`<&%R
M7VEN:71?96YV`$=,24)#7S(N,`!'3$E"0U\R+C(`1TQ)0D-?,BXS`$=,24)#
M7S(N,RXR`````@````(``@````````````(````#```````"``0`!0``````
M```"`````@`&``8```````(````#``(````"````!P```````P`"``(``@`"
M``(````"`````@`&`````@`"`````@`"```````"``(````````````"``(`
M!0`````````"```````"`````@`````````!``$``0`!``$``@`!``$````!
M``$``@`!``$``0`"``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$`
M`0`!`````0`!`````0`"`,<"```0````,````!!I:0T```8`E`4``!`````2
M:6D-```%`)X%`````````0`$``4#```0`````````!-I:0T```<`J`4``!``
M``!R&6D)```$`+(%```0````$FEI#0```P">!0``$````!!I:0T```(`E`4`
M```````H0P4(!@<``*!$!0@%7```I$0%"`5O```X0P4(!P$``#Q#!0@'`@``
M0$,%"`<#``!$0P4(!P0``$A#!0@'!0``3$,%"`<&``!00P4(!TP``%1#!0@'
M!P``6$,%"`<)``!<0P4(!PH``&!#!0@'"P``9$,%"`<,``!H0P4(!PT``&Q#
M!0@'#@``<$,%"`</``!T0P4(!Q```'A#!0@'$0``?$,%"`<2``"`0P4(!Q,`
M`(1#!0@'%```B$,%"`<5``",0P4(!Q8``)!#!0@'%P``E$,%"`<8``"80P4(
M!QD``)Q#!0@'&@``H$,%"`<;``"D0P4(!QP``*A#!0@''0``K$,%"`<>``"P
M0P4(!Q\``+1#!0@'(```N$,%"`<A``"\0P4(!R(``,!#!0@':```Q$,%"`=5
M``#(0P4(!R,``,Q#!0@')```T$,%"`<E``#40P4(!R8``-A#!0@')P``W$,%
M"`<H``#@0P4(!RD``.1#!0@'*@``Z$,%"`<K``#L0P4(!RP``/!#!0@'+0``
M]$,%"`<N``#X0P4(!R\``/Q#!0@',````$0%"`<Q```$1`4(!S(```A$!0@'
M,P``#$0%"`<T```01`4(!S4``!1$!0@'-@``&$0%"`<W```<1`4(!S@``"!$
M!0@'.0``)$0%"`<Z```H1`4(!SL``"Q$!0@'/```,$0%"`<]```T1`4(!SX`
M`#A$!0@'/P``/$0%"`=```!`1`4(!T$``$1$!0@'0@``2$0%"`=#``!,1`4(
M!T0``%!$!0@'10``5$0%"`=&``!81`4(!T<``%Q$!0@'2```8$0%"`=)``!D
M1`4(!TH``&A$!0@'2P``58GE4X/L!.@`````6X'#9*P``(N3_/___X72=`7H
MC@```.A-!0``Z&@]``!86\G#_S4P0P4(_R4T0P4(`````/\E.$,%"&@`````
MZ>#_____)3Q#!0AH"````.G0_____R5`0P4(:!````#IP/____\E1$,%"&@8
M````Z;#_____)4A#!0AH(````.F@_____R5,0P4(:"@```#ID/____\E4$,%
M"&@P````Z8#_____)51#!0AH.````.EP_____R580P4(:$````#I8/____\E
M7$,%"&A(````Z5#_____)6!#!0AH4````.E`_____R5D0P4(:%@```#I,/__
M__\E:$,%"&A@````Z2#_____)6Q#!0AH:````.D0_____R5P0P4(:'````#I
M`/____\E=$,%"&AX````Z?#^____)7A#!0AH@````.G@_O___R5\0P4(:(@`
M``#IT/[___\E@$,%"&B0````Z<#^____)81#!0AHF````.FP_O___R6(0P4(
M:*````#IH/[___\EC$,%"&BH````Z9#^____)9!#!0AHL````.F`_O___R64
M0P4(:+@```#I</[___\EF$,%"&C`````Z6#^____)9Q#!0AHR````.E0_O__
M_R6@0P4(:-````#I0/[___\EI$,%"&C8````Z3#^____):A#!0AHX````.D@
M_O___R6L0P4(:.@```#I$/[___\EL$,%"&CP````Z0#^____);1#!0AH^```
M`.GP_?___R6X0P4(:``!``#IX/W___\EO$,%"&@(`0``Z=#]____)<!#!0AH
M$`$``.G`_?___R7$0P4(:!@!``#IL/W___\ER$,%"&@@`0``Z:#]____)<Q#
M!0AH*`$``.F0_?___R700P4(:#`!``#I@/W___\EU$,%"&@X`0``Z7#]____
M)=A#!0AH0`$``.E@_?___R7<0P4(:$@!``#I4/W___\EX$,%"&A0`0``Z4#]
M____)>1#!0AH6`$``.DP_?___R7H0P4(:&`!``#I(/W___\E[$,%"&AH`0``
MZ1#]____)?!#!0AH<`$``.D`_?___R7T0P4(:'@!``#I\/S___\E^$,%"&B`
M`0``Z>#\____)?Q#!0AHB`$``.G0_/___R4`1`4(:)`!``#IP/S___\E!$0%
M"&B8`0``Z;#\____)0A$!0AHH`$``.F@_/___R4,1`4(:*@!``#ID/S___\E
M$$0%"&BP`0``Z8#\____)11$!0AHN`$``.EP_/___R481`4(:,`!``#I8/S_
M__\E'$0%"&C(`0``Z5#\____)2!$!0AHT`$``.E`_/___R4D1`4(:-@!``#I
M,/S___\E*$0%"&C@`0``Z2#\____)2Q$!0AHZ`$``.D0_/___R4P1`4(:/`!
M``#I`/S___\E-$0%"&CX`0``Z?#[____)3A$!0AH``(``.G@^____R4\1`4(
M:`@"``#IT/O___\E0$0%"&@0`@``Z<#[____)41$!0AH&`(``.FP^____R5(
M1`4(:"`"``#IH/O___\E3$0%"&@H`@``Z9#[____)5!$!0AH,`(``.F`^___
M_R541`4(:#@"``#I</O___\E6$0%"&A``@``Z6#[____)5Q$!0AH2`(``.E0
M^____R5@1`4(:%`"``#I0/O___\E9$0%"&A8`@``Z3#[____)6A$!0AH8`(`
M`.D@^___`````#'M7HGA@^3P4%12:&#3!`AH<-,$"%%6:$+0!`CH6_S___20
MD)"0D)"0D)"0D)"0D%6)Y8/L"(`]N$0%"`!T#.L<@\`$HW1$!0C_TJ%T1`4(
MBQ"%TG7KQ@6X1`4(`<G#D%6)Y8/L"*$L0@4(A<!T$K@`````A<!T"<<$)"Q"
M!0C_T,G#D%6)Y8/L*,=%_*C4!`C'!"0`````Z._^__^+`(D$).CE^___B<*+
M1?R)1"0,QT0D"!R9!`C'1"0$LM0$"(D4).B4_O__R<-5B>53@>PD$```QT0D
M"/\/``"-A?CO__^)1"0$QP0DSM0$".C*_?__B47X@WWX`'X6BT7X@^@!#[:$
M!?CO__^$P'4$@VWX`8-]^`!^6XM%^(E$)`C'1"0$+P```(V%^.___XD$).CH
M_?__A<!T.HM=^,<$)`````#H1?[__XL`B00DZ#O[__^)PHE<)`R-A?CO__^)
M1"0(BT4,B40D!(D4).A\_/__ZR['!"0`````Z`[^__^+`(D$).@$^___B<*+
M11")1"0(BT4,B40D!(D4).C,^O__@<0D$```6UW#58GE@^PH@WT(`'0)H:!$
M!0B%P'4,QT7L`````.F@````BT4(B47TZP2#1?0!BU7T#[8"A,!T"HM-]`^V
M`3P]=>B+5?2+10B)T2G!B4WPH:!$!0B)1?CK5(M%\(E$)`B+50B)5"0$BTW\
MB0PDZ!+]__^%P'4SBT7P`T7\#[8`/#UU)HM5^*&@1`4(B=$IP8G(P?@"B<*+
M10R)$(M%\`-%_(/``8E%[.L9@T7X!(M%^(L`B47\@WW\`'6>QT7L`````(M%
M[,G#58GE@^P8C47\B40D!(M%"(D$).@B____R<-5B>53@^PTBU4,#[8"/#UU
M!(-%#`&+30R)#"3H$_O__XE%^(U%](E$)`2+10B)!"3HZ_[__XE%X(-]X`!T
M0HM%X(D$).CJ^O__.T7X#X(#`0``BU4,#[8"BTW@B`&+5>`/M@*$P`^5P(-%
MX`&#10P!A,!UWL=%W`````#IJ0$``(L-H$0%"(E-Z,=%Y`````#K"(-%Z`2#
M1>0!BU7HBP*%P'7OH<!$!0B%P'0UBT7DP>`"@\`(BQ6@1`4(B40D!(D4).A<
M^/__HZ!$!0BAH$0%"(7`=6/'1=S_____Z4@!``#'!<!$!0@!````BT7DP>`"
M@\`(B00DZ-?Z__^)1>B#?>@`=0S'1=S_____Z1@!``"+1>3!X`*+%:!$!0B)
M1"0(B50D!(M-Z(D,).@3^___BT7HHZ!$!0BAH$0%"(U0!(M%Y,'@`HT$`L<`
M`````(M%Y(E%](M5"(E5X.L$@T7@`8M-X`^V`83`=`J+5>`/M@(\/77HBT7T
MP>`"B<*AH$0%"(T<`HM5X(M%"(G1*<&)R`-%^(/``HD$).@T^O__B0.+`X7`
M=0G'1=S_____ZWF+1?3!X`*)PJ&@1`4(C00"BP")1>#K!(-%X`&+10@/M@"+
M5>"(`HM-X`^V`83`#Y7`@T4(`8/P`83`=0J+5>`/M@(\/771BTW@Q@$]@T7@
M`8M5#`^V`HM-X(@!BU7@#[8"A,`/E<"#1>`!@T4,`83`==['1=P`````BT7<
M@\0T6UW#58GE@^PHZRZ+1?S!X`*)PJ&@1`4(`<*)5>R+1>R#P`2+`(M5[(D"
MBU7LBP*%P'0&@T7L!.ODC47\B40D!(M%"(D$).BF_/__A<!UO,G#58GE@>PH
M(```QT7X`````.@N]O__QT0D#.'4!`B)1"0(QT0D!.74!`B-A??O__^)!"3H
M[/7__XE%_(-]_`!Y#\>%[-___P````#IA@```,=$)`@`$```C87VW___B40D
M!(V%]^___XD$).A$^?__B47\@WW\`'D,QX7LW___`````.M1BT7\@\`!B00D
MZ,'X__^)1?B#??@`=0S'A>S?__\`````ZRZ+1?R)1"0(C87VW___B40D!(M%
M^(D$).C0]___BT7\`T7XQ@``BT7XB87LW___BX7LW___R<-5B>6#[`CH&/__
M_\G#58GE@>PH$```QP0D\=0$".AG_/__B47\H7A$!0B)1"0$BT4(B00DZ"WX
M__^%P'0ABT4(B40D!,<$)/K4!`CH4_S__XM%"(F%[.___^GP`0``BT4(B00D
MZ&WW__^)1?2A?$0%"(E$)`2+10R)!"3H)OC__XE%\.F@`0``BT7P#[8`A,!U
M!\=%\`?5!`B#??P`=#.+1?")1"0$BT7\B00DZ!7Y__^%P'4=H7Q$!0B)1"0$
MQP0D`````.C<]___B47PZ58!``"+1?")!"3H^?;__XE%^.L-@VWX`8M%^`-%
M\,8``(M5\(/J`8M%^(T$`@^V$*%X1`4(#[8`.,)TV(M%^(/``0-%]#W_#P``
M?B&+10B)1"0$QP0D^M0$".AV^___BT4(B87L[___Z1,!``"+%7A$!0B+10B)
M1"00B50D#(M%\(E$)`C'1"0$"=4$"(V%\.___XD$).C=\___QP0D`````.@Q
M^/__BP")!"3H)_7__XD$).@_]___B40D!(V%\.___XD$).B!,```A<!U<\<$
M)`````#H_??__XL`B00DZ//T__^)!"3H"_?__XM`$"4`\```/0"```!U1L=$
M)`0!````C87P[___B00DZ#;U__^%P'4LC87P[___B40D!,<$)/K4!`CHJ?K_
M_XV%\.___XD$).B.]___B87L[___ZSZA?$0%"(E$)`3'!"0`````Z('V__^)
M1?"#??``#X56_O__BT4(B40D!,<$)/K4!`CH7OK__XM%"(F%[.___XN%[.__
M_\G#58GE@^P0BT4(B47XBT4(B47\ZQ^+1?P/MA"A>$0%"`^V`#C"=0F+1?R#
MP`&)1?B#1?P!BT7\#[8`A,!UUXM%^,G#58GE@^P8@WT(`'0*BT4(#[8`A,!U
M%,<$)`?5!`CHW/;__XE%^.G_````BT4(B00DZ`GU__\#10B#Z`&)1?SK!(-M
M_`&+1?P[10AV&8M5_`^V`HL5>$0%"`^V$CC0=.'K!(-M_`&+3?P[30AV$XM5
M_`^V`HL5>$0%"`^V$CC0=>&+3?P[30AU-HM5_`^V`HL5>$0%"`^V$CC0=1''
M!"0'U00(Z%?V__^)1?CK?:%X1`4(B00DZ$7V__^)1?CK:X-M_`&+3?P[30AV
M$XM5_`^V`HL5>$0%"`^V$CC0=.&+5?R+10B)T2G!B<B#P`(]`!```'8)QT7X
M`````.LMBU7\BT4(B=$IP8G(@\`!B40D"(M%"(E$)`3'!"3@1`4(Z%SR___'
M1?C@1`4(BT7XR<-5B>6#[$BAO-4$"(E%VJ'`U00(B47>H<35!`B)1>*AR-4$
M"(E%YJ',U00(B47JH=#5!`B)1>ZAU-4$"(E%\J'8U00(B47V#[<%W-4$"&:)
M1?K'!"00U00(Z++Z___'!"0@U00(Z*;Z___'!"3QU`0(Z)KZ___'!"0LU00(
MZ([Z___'!"0VU00(Z(+Z___'!"1`U00(Z';Z___'!"3ZU`0(Z&KZ___'!"1*
MU00(Z%[Z___'!"13U00(Z%+Z___'!"1>U00(Z/KW__^)1?R#??P`=!.+1?R)
M1"0$QP0D-M4$".CX]___QP0D;]4$".C2]___B47\@WW\`'03BT7\B40D!,<$
M)('5!`CHT/?__\<$)(S5!`CHJO?__XE%_(-]_`!T%8M%_(E$)`3'!"3QU`0(
MZ*CW___K:,<$))S5!`CH@/?__XE%_(-]_`!T%8M%_(E$)`3'!"0LU00(Z'[W
M___K/HU%VH/`$8E%_,=$)`@*````QT0D!*W5!`B+1?R)!"3H^_/__X7`=1:+
M1?R#P`J)1"0$QP0D+-4$".@^]___QT0D!+C5!`C'!"00U00(Z"KW___)PU6)
MY8/L&*&`1`4(@_C_=4''!"0LU00(Z/+V__^)1?R#??P`=!V+1?P/M@"$P'03
MBT7\#[8`/#!T"<=%[`$```#K!\=%[`````"+1>RC@$0%"*&`1`4(R<-5B>6!
M['`!``"+10B#P!R)1>#'1=P`````ZT^+1>"+`(E%Y(-%X`2+3=R+1>3!X!B)
MPH'B````_XM%Y,'@""4``/\`"<*+1>3!Z`@E`/\```G"BT7DP>@8)?\````)
MT(F$C9S^__^#1=P!@WW<#WZKQT7<$````.M?BTW<BT7<@^@#BY2%G/[__XM%
MW(/H"(N$A9S^__\QPHM%W(/H#HN$A9S^__\QPHM%W(/H$(N$A9S^__\QT(F$
MC9S^__^+5=R+1=R+A(6<_O__P<@?B825G/[__X-%W`&#?=Q/?IN+10B+`(E%
MZ(M%"(M`!(E%[(M%"(M`"(E%\(M%"(M`#(E%](M%"(M`$(E%^(V%G/[__XE%
M_(M%Z(G!P<D;BT7PBU7L(<*+1>SWT"-%]`G0C00!B<(#5?B+1?R+`(T$`@69
M>8):B47D@T7\!,%-[`*+1>2)P<')&XM%[(M5Z"'"BT7H]]`C1?`)T(T$`8G"
M`U7TBT7\BP"-!`(%F7F"6HE%^(-%_`3!3>@"BT7XB<'!R1N+1>B+5>0APHM%
MY/?0(T7L"="-!`&)P@-5\(M%_(L`C00"!9EY@EJ)1?2#1?P$P4WD`HM%](G!
MP<D;BT7DBU7X(<*+1?CWT"-%Z`G0C00!B<(#5>R+1?R+`(T$`@69>8):B47P
M@T7\!,%-^`*+1?")P<')&XM%^(M5]"'"BT7T]]`C1>0)T(T$`8G"`U7HBT7\
MBP"-!`(%F7F"6HE%[(-%_`3!3?0"BT7LB<'!R1N+1?2+5?`APHM%\/?0(T7X
M"="-!`&)P@-5Y(M%_(L`C00"!9EY@EJ)1>B#1?P$P4WP`HM%Z(G!P<D;BT7P
MBU7L(<*+1>SWT"-%]`G0C00!B<(#5?B+1?R+`(T$`@69>8):B47D@T7\!,%-
M[`*+1>2)P<')&XM%[(M5Z"'"BT7H]]`C1?`)T(T$`8G"`U7TBT7\BP"-!`(%
MF7F"6HE%^(-%_`3!3>@"BT7XB<'!R1N+1>B+5>0APHM%Y/?0(T7L"="-!`&)
MP@-5\(M%_(L`C00"!9EY@EJ)1?2#1?P$P4WD`HM%](G!P<D;BT7DBU7X(<*+
M1?CWT"-%Z`G0C00!B<(#5>R+1?R+`(T$`@69>8):B47P@T7\!,%-^`*+1?")
MP<')&XM%^(M5]"'"BT7T]]`C1>0)T(T$`8G"`U7HBT7\BP"-!`(%F7F"6HE%
M[(-%_`3!3?0"BT7LB<'!R1N+1?2+5?`APHM%\/?0(T7X"="-!`&)P@-5Y(M%
M_(L`C00"!9EY@EJ)1>B#1?P$P4WP`HM%Z(G!P<D;BT7PBU7L(<*+1>SWT"-%
M]`G0C00!B<(#5?B+1?R+`(T$`@69>8):B47D@T7\!,%-[`*+1>2)P<')&XM%
M[(M5Z"'"BT7H]]`C1?`)T(T$`8G"`U7TBT7\BP"-!`(%F7F"6HE%^(-%_`3!
M3>@"BT7XB<'!R1N+1>B+5>0APHM%Y/?0(T7L"="-!`&)P@-5\(M%_(L`C00"
M!9EY@EJ)1?2#1?P$P4WD`HM%](G!P<D;BT7DBU7X(<*+1?CWT"-%Z`G0C00!
MB<(#5>R+1?R+`(T$`@69>8):B47P@T7\!,%-^`*+1?")P<')&XM%^(M5]"'"
MBT7T]]`C1>0)T(T$`8G"`U7HBT7\BP"-!`(%F7F"6HE%[(-%_`3!3?0"BT7L
MB<'!R1N+1?2+5?`APHM%\/?0(T7X"="-!`&)P@-5Y(M%_(L`C00"!9EY@EJ)
M1>B#1?P$P4WP`HM%Z(G!P<D;BT7PBU7L(<*+1>SWT"-%]`G0C00!B<(#5?B+
M1?R+`(T$`@69>8):B47D@T7\!,%-[`*+1>2)P<')&XM%[(M5Z"'"BT7H]]`C
M1?`)T(T$`8G"`U7TBT7\BP"-!`(%F7F"6HE%^(-%_`3!3>@"BT7XB<+!RAN+
M1>@S1>0S1>R-!`*)P@-5\(M%_(L`C00"!:'KV6Z)1?2#1?P$P4WD`HM%](G"
MP<H;BT7D,T7X,T7HC00"B<(#5>R+1?R+`(T$`@6AZ]ENB47P@T7\!,%-^`*+
M1?")PL'*&XM%^#-%]#-%Y(T$`HG"`U7HBT7\BP"-!`(%H>O9;HE%[(-%_`3!
M3?0"BT7LB<+!RAN+1?0S1?`S1?B-!`*)P@-5Y(M%_(L`C00"!:'KV6Z)1>B#
M1?P$P4WP`HM%Z(G"P<H;BT7P,T7L,T7TC00"B<(#5?B+1?R+`(T$`@6AZ]EN
MB47D@T7\!,%-[`*+1>2)PL'*&XM%[#-%Z#-%\(T$`HG"`U7TBT7\BP"-!`(%
MH>O9;HE%^(-%_`3!3>@"BT7XB<+!RAN+1>@S1>0S1>R-!`*)P@-5\(M%_(L`
MC00"!:'KV6Z)1?2#1?P$P4WD`HM%](G"P<H;BT7D,T7X,T7HC00"B<(#5>R+
M1?R+`(T$`@6AZ]ENB47P@T7\!,%-^`*+1?")PL'*&XM%^#-%]#-%Y(T$`HG"
M`U7HBT7\BP"-!`(%H>O9;HE%[(-%_`3!3?0"BT7LB<+!RAN+1?0S1?`S1?B-
M!`*)P@-5Y(M%_(L`C00"!:'KV6Z)1>B#1?P$P4WP`HM%Z(G"P<H;BT7P,T7L
M,T7TC00"B<(#5?B+1?R+`(T$`@6AZ]ENB47D@T7\!,%-[`*+1>2)PL'*&XM%
M[#-%Z#-%\(T$`HG"`U7TBT7\BP"-!`(%H>O9;HE%^(-%_`3!3>@"BT7XB<+!
MRAN+1>@S1>0S1>R-!`*)P@-5\(M%_(L`C00"!:'KV6Z)1?2#1?P$P4WD`HM%
M](G"P<H;BT7D,T7X,T7HC00"B<(#5>R+1?R+`(T$`@6AZ]ENB47P@T7\!,%-
M^`*+1?")PL'*&XM%^#-%]#-%Y(T$`HG"`U7HBT7\BP"-!`(%H>O9;HE%[(-%
M_`3!3?0"BT7LB<+!RAN+1?0S1?`S1?B-!`*)P@-5Y(M%_(L`C00"!:'KV6Z)
M1>B#1?P$P4WP`HM%Z(G"P<H;BT7P,T7L,T7TC00"B<(#5?B+1?R+`(T$`@6A
MZ]ENB47D@T7\!,%-[`*+1>2)PL'*&XM%[#-%Z#-%\(T$`HG"`U7TBT7\BP"-
M!`(%H>O9;HE%^(-%_`3!3>@"BT7XB<+!RAN+1>@S1>0S1>R-!`*)P@-5\(M%
M_(L`C00"!:'KV6Z)1?2#1?P$P4WD`HM%](G"P<H;BT7D,T7X,T7HC00"B<(#
M5>R+1?R+`(T$`@6AZ]ENB47P@T7\!,%-^`*+1?")P<')&XM%Y`M%^(G"(U7T
MBT7D(T7X"="-!`&)P@-5Z(M%_(L`C00"+21#Y'")1>R#1?P$P4WT`HM%[(G!
MP<D;BT7X"T7TB<(C5?"+1?@C1?0)T(T$`8G"`U7DBT7\BP"-!`(M)$/D<(E%
MZ(-%_`3!3?`"BT7HB<'!R1N+1?0+1?")PB-5[(M%]"-%\`G0C00!B<(#5?B+
M1?R+`(T$`BTD0^1PB47D@T7\!,%-[`*+1>2)P<')&XM%\`M%[(G"(U7HBT7P
M(T7L"="-!`&)P@-5](M%_(L`C00"+21#Y'")1?B#1?P$P4WH`HM%^(G!P<D;
MBT7L"T7HB<(C5>2+1>PC1>@)T(T$`8G"`U7PBT7\BP"-!`(M)$/D<(E%](-%
M_`3!3>0"BT7TB<'!R1N+1>@+1>2)PB-5^(M%Z"-%Y`G0C00!B<(#5>R+1?R+
M`(T$`BTD0^1PB47P@T7\!,%-^`*+1?")P<')&XM%Y`M%^(G"(U7TBT7D(T7X
M"="-!`&)P@-5Z(M%_(L`C00"+21#Y'")1>R#1?P$P4WT`HM%[(G!P<D;BT7X
M"T7TB<(C5?"+1?@C1?0)T(T$`8G"`U7DBT7\BP"-!`(M)$/D<(E%Z(-%_`3!
M3?`"BT7HB<'!R1N+1?0+1?")PB-5[(M%]"-%\`G0C00!B<(#5?B+1?R+`(T$
M`BTD0^1PB47D@T7\!,%-[`*+1>2)P<')&XM%\`M%[(G"(U7HBT7P(T7L"="-
M!`&)P@-5](M%_(L`C00"+21#Y'")1?B#1?P$P4WH`HM%^(G!P<D;BT7L"T7H
MB<(C5>2+1>PC1>@)T(T$`8G"`U7PBT7\BP"-!`(M)$/D<(E%](-%_`3!3>0"
MBT7TB<'!R1N+1>@+1>2)PB-5^(M%Z"-%Y`G0C00!B<(#5>R+1?R+`(T$`BTD
M0^1PB47P@T7\!,%-^`*+1?")P<')&XM%Y`M%^(G"(U7TBT7D(T7X"="-!`&)
MP@-5Z(M%_(L`C00"+21#Y'")1>R#1?P$P4WT`HM%[(G!P<D;BT7X"T7TB<(C
M5?"+1?@C1?0)T(T$`8G"`U7DBT7\BP"-!`(M)$/D<(E%Z(-%_`3!3?`"BT7H
MB<'!R1N+1?0+1?")PB-5[(M%]"-%\`G0C00!B<(#5?B+1?R+`(T$`BTD0^1P
MB47D@T7\!,%-[`*+1>2)P<')&XM%\`M%[(G"(U7HBT7P(T7L"="-!`&)P@-5
M](M%_(L`C00"+21#Y'")1?B#1?P$P4WH`HM%^(G!P<D;BT7L"T7HB<(C5>2+
M1>PC1>@)T(T$`8G"`U7PBT7\BP"-!`(M)$/D<(E%](-%_`3!3>0"BT7TB<'!
MR1N+1>@+1>2)PB-5^(M%Z"-%Y`G0C00!B<(#5>R+1?R+`(T$`BTD0^1PB47P
M@T7\!,%-^`*+1?")P<')&XM%Y`M%^(G"(U7TBT7D(T7X"="-!`&)P@-5Z(M%
M_(L`C00"+21#Y'")1>R#1?P$P4WT`HM%[(G!P<D;BT7X"T7TB<(C5?"+1?@C
M1?0)T(T$`8G"`U7DBT7\BP"-!`(M)$/D<(E%Z(-%_`3!3?`"BT7HB<+!RAN+
M1?`S1>PS1?2-!`*)P@-5^(M%_(L`C00"+2H^G36)1>2#1?P$P4WL`HM%Y(G"
MP<H;BT7L,T7H,T7PC00"B<(#5?2+1?R+`(T$`BTJ/ITUB47X@T7\!,%-Z`*+
M1?B)PL'*&XM%Z#-%Y#-%[(T$`HG"`U7PBT7\BP"-!`(M*CZ=-8E%](-%_`3!
M3>0"BT7TB<+!RAN+1>0S1?@S1>B-!`*)P@-5[(M%_(L`C00"+2H^G36)1?"#
M1?P$P4WX`HM%\(G"P<H;BT7X,T7T,T7DC00"B<(#5>B+1?R+`(T$`BTJ/ITU
MB47L@T7\!,%-]`*+1>R)PL'*&XM%]#-%\#-%^(T$`HG"`U7DBT7\BP"-!`(M
M*CZ=-8E%Z(-%_`3!3?`"BT7HB<+!RAN+1?`S1>PS1?2-!`*)P@-5^(M%_(L`
MC00"+2H^G36)1>2#1?P$P4WL`HM%Y(G"P<H;BT7L,T7H,T7PC00"B<(#5?2+
M1?R+`(T$`BTJ/ITUB47X@T7\!,%-Z`*+1?B)PL'*&XM%Z#-%Y#-%[(T$`HG"
M`U7PBT7\BP"-!`(M*CZ=-8E%](-%_`3!3>0"BT7TB<+!RAN+1>0S1?@S1>B-
M!`*)P@-5[(M%_(L`C00"+2H^G36)1?"#1?P$P4WX`HM%\(G"P<H;BT7X,T7T
M,T7DC00"B<(#5>B+1?R+`(T$`BTJ/ITUB47L@T7\!,%-]`*+1>R)PL'*&XM%
M]#-%\#-%^(T$`HG"`U7DBT7\BP"-!`(M*CZ=-8E%Z(-%_`3!3?`"BT7HB<+!
MRAN+1?`S1>PS1?2-!`*)P@-5^(M%_(L`C00"+2H^G36)1>2#1?P$P4WL`HM%
MY(G"P<H;BT7L,T7H,T7PC00"B<(#5?2+1?R+`(T$`BTJ/ITUB47X@T7\!,%-
MZ`*+1?B)PL'*&XM%Z#-%Y#-%[(T$`HG"`U7PBT7\BP"-!`(M*CZ=-8E%](-%
M_`3!3>0"BT7TB<+!RAN+1>0S1?@S1>B-!`*)P@-5[(M%_(L`C00"+2H^G36)
M1?"#1?P$P4WX`HM%\(G"P<H;BT7X,T7T,T7DC00"B<(#5>B+1?R+`(T$`BTJ
M/ITUB47L@T7\!,%-]`*+1>R)PL'*&XM%]#-%\#-%^(T$`HG"`U7DBT7\BP"-
M!`(M*CZ=-8E%Z(-%_`3!3?`"BT7HB<+!RAN+1?`S1>PS1?2-!`*)P@-5^(M%
M_(L`C00"+2H^G36)1>2#1?P$P4WL`HM%Y(G"P<H;BT7L,T7H,T7PC00"B<(#
M5?2+1?R+`(T$`BTJ/ITUB47X@T7\!,%-Z`*+10B+`(G"`U7XBT4(B1"+10B+
M0`2)P@-5Y(M%"(E0!(M%"(M`"(G"`U7HBT4(B5`(BT4(BT`,B<(#5>R+10B)
M4`R+10B+0!")P@-5\(M%"(E0$,G#58GEBT4(QP`!(T5GBT4(QT`$B:O-[XM%
M",=`"/[<NIB+10C'0`QV5#(0BT4(QT`0\.'2PXM%",=`%`````"+10C'0!@`
M````BT4(QT!<`````%W#58GE@^PHBT4(BU`4BT40P>`#C00"B47\BT4(BT`4
M.T7\=@^+10B+0!B-4`&+10B)4!B+50B+1?R)0A2+10B+4!B+11#!Z!T!PHM%
M"(E0&(M%"(M`7(7`#X2G````BT4(BU!<N$`````IT(E%^(M%^#M%$'X&BT40
MB47XBTWXBU4(@\(<BT4(BT!<`<*)3"0(BT4,B40D!(D4).B\WO__BT7X*440
MBT7X`44,BT4(BT!<B<(#5?B+10B)4%R+10B+0%R#^$!U:(M%"(D$).BF[/__
MZS"+10B#P!S'1"0(0````(M5#(E4)`2)!"3H:M[__X-%#$"#;1!`BT4(B00D
MZ'3L__^#?1`_?\J+11"+50B#PAR)1"0(BT4,B40D!(D4).@UWO__BU4(BT40
MB4)<R<-5B>6#[`2+10R)!"3H-NS__XM%#(L`P>@8B<*+10B($(M5"(/"`8M%
M#(L`P>@0B`*+50B#P@*+10R+`,'H"(@"BU4(@\(#BT4,BP"(`HM5"(/"!(M%
M#(M`!,'H&(@"BU4(@\(%BT4,BT`$P>@0B`*+50B#P@:+10R+0`3!Z`B(`HM5
M"(/"!XM%#(M`!(@"BU4(@\((BT4,BT`(P>@8B`*+50B#P@F+10R+0`C!Z!"(
M`HM5"(/""HM%#(M`",'H"(@"BU4(@\(+BT4,BT`(B`*+50B#P@R+10R+0`S!
MZ!B(`HM5"(/"#8M%#(M`#,'H$(@"BU4(@\(.BT4,BT`,P>@(B`*+50B#P@^+
M10R+0`R(`HM5"(/"$(M%#(M`$,'H&(@"BU4(@\(1BT4,BT`0P>@0B`*+50B#
MPA*+10R+0!#!Z`B(`HM5"(/"$XM%#(M`$(@"R<-5B>6#["B+10R+0!2)1?B+
M10R+0!B)1?R+1?C!Z`.#X#^)1?2+50R#PAR+1?2-!`+&`("#1?0!@WWT.'Y5
MN$`````K1?2)P8M5#(/"'(M%](T$`HE,)`C'1"0$`````(D$).@PV___BT4,
MB00DZ(+J__^+10R#P!S'1"0(.````,=$)`0`````B00DZ`?;___K*K@X````
M*T7TB<&+50R#PAR+1?2-!`*)3"0(QT0D!`````")!"3HV]K__XM%_,'H&(G"
MBT4,B%!4BT7\P>@0B<*+10R(4%6+1?S!Z`B)PHM%#(A05HM%_(G"BT4,B%!7
MBT7XP>@8B<*+10R(4%B+1?C!Z!")PHM%#(A068M%^,'H"(G"BT4,B%!:BT7X
MB<*+10R(4%N+10R)1"0$BT4(B00DZ'7]___)PU6)Y8/L&,=%]`````#'1?@`
M````Z.3;__^)1?R#??P`=!:+1?R)!"3HL-O__XE%^(M%^(L`B47TBT7TR<-5
MB>53@^Q$QT7L`````,=%\`````#'1=3>U00(QT78[M4$",=%W/;5!`C'1>`#
MU@0(QT7D"-8$",=%Z!K6!`C'1?@`````QT7T`````.G$````BT7LB00DZ-;?
M__^)1?"#??``=`J+1?`/M@"$P'47BT4(B40D!(M%[(D$).C+W___Z8L```"+
M10B)1"0$BT7PB00DZ'?;__^%P'5UBT4(B00DZ-C:__^)PZ%\1`4(B00DZ,G:
M__\!PXM%\(D$).B\VO__C00#@\`"B00DZ$[;__^)1?B+%7Q$!0B+1?")1"00
MB50D#(M%"(E$)`C'1"0$"=4$"(M%^(D$).CPU___BT7XB40D!(M%[(D$).@[
MW___@T7T`8M%](M$A=2)1>R+1>P/M@"$P`^%)/___X/$1%M=PU6)Y5.![#2!
M``#'1<P`````QT70`````,=%U`````#'1;0;U@0(QT6X(]8$",=%O`?5!`C'
M1<`:U@0(QT6<@=4$",=%H"C6!`C'1:0OU@0(QT6H-]8$",=%K#S6!`C'1;`:
MU@0(QT600-8$",=%E$76!`C'19@:U@0(QT783M8$",=%W!K6!`C'1>``````
MQT7D`````,=%Z`````#'1?@`````QP0D\=0$".A/WO__B474@WW4`'0KBT74
M#[8`A,!T(8M%U(D$).C^_?__BT74B00DZ#/;__^)A>A^___IZP4``.BF_?__
MB47D@WWD`'5)QT7$`````.LFBT70B00DZ/G=__^)1=2#?=0`=`Z+1=2)!"3H
M\MK__XE%Y(-%Q`&#?>0`=12+1<2+1(60B470BT70#[8`A,!UP(-]Y`!U"<=%
MY%/6!`CK/HM%Y(E%R.LLZ'78__^+$(M%R`^V``^^P`'`C00"#[<`#[?`@^`(
MA<!U!HM%R,8`7X-%R`&+1<@/M@"$P'7*QT7$`````.G,````BT70B00DZ&#=
M__^)1=2#?=0`#X2P````QP0D`````.ADVO__BP")!"3H6M?__XD$).ARV?__
MB40D!(M%U(D$).CW$@``A<!U?\<$)`````#H,]K__XL`B00DZ"G7__^)!"3H
M0=G__XM`$"4`\```/0!```!T+<<$)`````#H!MK__XL`B00DZ/S6__^)!"3H
M%-G__XM`$"4`\```/0"@``!U)<=$)`0"````BT74B00DZ$+7__^%P'4.BT74
MB00DZ+/9__^)1<R#1<0!@WW,`'48BT7$BT2%G(E%T(M%T`^V`(3`#X46____
MQT7$`````.FT````QP0D`````.B&V?__BP")!"3H?-;__XD$).B4V/__B40D
M!(M%U(D$).@9$@``A<!U?\<$)`````#H5=G__XL`B00DZ$O6__^)!"3H8]C_
M_XM`$"4`\```/0!```!T+<<$)`````#H*-G__XL`B00DZ![6__^)!"3H-MC_
M_XM`$"4`\```/0"@``!U)<=$)`0"````BT74B00DZ&36__^%P'4.BT74B00D
MZ-78__^)1<R#1<0!@WW,`'48BT7$BT2%M(E%U(M%U`^V`(3`#X4N____BT7,
MB00DZ.76__^)PXM%V(D$).C8UO__`<.+1>2)!"3HR];__P'#BT7<B00DZ+[6
M__^-!`,%``0``(E%^(M%^(D$).A(U___B47HBQ5X1`4(BT7DB40D%(M%V(E$
M)!")5"0,BT7,B40D",=$)`1:U@0(BT7HB00DZ./3___'1"0$[0$``(M%Z(D$
M).@`U/__QP0D`]8$".@'V___B474BT74B00DZ`;8__^)PHM%"(L`B50D!(D$
M).AJWO__B47@@WW@`'4(BT4(BP")1>#HPN/__X7`#X4G`@``QT0D!`````"+
M1>")!"3H@M?__XE%[(-][``/A`<"``#'1"0,`@```,=$)`3N____QT0D"/__
M__^+1>R)!"3H,M3__\=$)`@&````C84$?___B40D!(M%[(D$).B5U/__#[:%
M!'___X3`#X7!````#[:%!7___SQ##X6R````#[:%!G___SQ!#X6C````#[:%
M!W___SQ##X64````#[:%"'___SQ(#X6%````#[:%"7___SQ%=7K'1"0,`@``
M`,=$)`3&____QT0D"/____^+1>R)!"3HG-/__\=$)`@I````C84$?___B40D
M!(M%[(D$).C_T___BQ5X1`4(BT7<B40D%(V%!'___XE$)!")5"0,BT7HB40D
M",=$)`1CU@0(BT7HB00DZ%K2___I00$``(V%!/___XD$).@(]?__ZQ^+1?")
M1"0(C84$?___B40D!(V%!/___XD$).@[]?__QT0D"`"```"-A01___^)1"0$
MBT7LB00DZ'G3__^)1?"#??``?[N+1>R)!"3H]=3__XV%!/___XE$)`2-A?!^
M__^)!"3H=O?__\=%]`````#K-8M%]`^VA`7P?O__#[;(BT7T`<")PHV%9___
M_P'0B4PD",=$)`1RU@0(B00DZ*/1__^#1?0!@WWT$W[%QD6/`(L5>$0%"(M%
MW(E$)!2-A6?___^)1"00B50D#(M%Z(E$)`C'1"0$8]8$"(M%Z(D$).A@T?__
MZTK'1"0$N-4$",<$)"S5!`CHI]C__^AET?__B<*+#7A$!0B+1=R)1"04B50D
M$(E,)`R+1>B)1"0(QT0D!'?6!`B+1>B)!"3H%-'__XM%Z(E$)`3'!"3QU`0(
MZ%[8__^+1>B)!"3H!OC__XM%Z(F%Z'[__XN%Z'[__X'$-($``%M=PU6)Y5.!
M[(0```#'1?0`````BT4(B00DZ++2__^)1>R#?>P`#X0I`0``Z?````"+1?"#
MP!/'1"0$!]4$"(D$).@:U?__A<`/A-(```"+1?"#P!/'1"0$A=8$"(D$).C\
MU/__A<`/A+0```"+10B)!"3H^=+__XG#BT7P@\`3B00DZ.G2__^-!`.#P`*)
M1?B+1?B)!"3H==/__XE%](M%\(/`$XE$)`R+10B)1"0(QT0D!(C6!`B+1?2)
M!"3H'M#__XU%C(E$)`2+1?2)!"3HX`P``(/X_W0JBT6<)0#P```]`$```'4;
M@WT,`'05QT0D!`$```"+1?2)!"3H`?___^L+BT7TB00DZ'+2__^+1?2)!"3H
M9]'__\=%]`````"+1>R)!"3H%=+__XE%\(-]\``/A?C^__^+1>R)!"3HC=+_
M_X-]"`!T"XM%"(D$).C<TO__@<2$````6UW#58GE@^P8BT4(B00DZ,3<__^)
M1?B+1?B)!"3H=-S__XE%_.B1W___A<!T3H-]"`!T2(M%"`^V`(3`=#['1"0$
M3M8$"(M%_(D$).A5TO__.T7\=2;'1"0$`0```(M%"(D$).@__O__QT0D!```
M``"+1?B)!"3H+/[__\G#58GE4X/L%,<$)`````#H5=/__XL`B00DZ$O0__^)
M!"3H\\[__XL`BU@$QP0D`````.@RT___BP")!"3H*-#__XD$).APS___#[8`
MB$,8QP0D`````.@.T___BP")!"3H!-#__XD$).BLSO__BP"+6`3'!"0`````
MZ.O2__^+`(D$).CAS___B00DZ#G/__^+``^W0!!F)?\!9HE#&L<$)`````#H
MO]+__XL`B00DZ+7/__^)!"3H7<[__XL`BU@$QP0D`````.B<TO__BP")!"3H
MDL___\=$)`@`````QT0D!!K6!`B)!"3H^M'__XE#',<$)`````#H:]+__XL`
MB00DZ&'/__^)!"3H"<[__XL`BU@$QP0D`````.A(TO__BP")!"3H/L___XD$
M).AFSO__BP")0R#'!"0`````Z"72__^+`(D$).@;S___B00DZ,/-__^+`(M`
M!(E%],<$)`````#H_]'__XL`B00DZ/7.__^)!"3H_=#__XL`A<!T*,<$)```
M``#HV]'__XL`B00DZ-'.__^)!"3HV=#__XL`BT!LB47XZP?'1?@`````BU7X
MBT7TB5`DQP0D`````.BCT?__BP")!"3HF<[__XD$).A!S?__BP"+0`3'0"@`
M````QP0D`````.AYT?__BP")!"3H;\[__XD$).@7S?__BP"+0`3'0"P`````
MQP0D`````.A/T?__BP")!"3H1<[__XD$).CMS/__BP"+6`3'!"0`````Z"S1
M__^+`(D$).@BSO__B00DZ-K0__^+`(E#,(/$%%M=PU6)Y8/L&,<$)`````#H
M_=#__XL`B00DZ//-___'1"0$_____XD$).@SSO__QP0D`````.C7T/__BP")
M!"3HS<W__\=$)`@`````QT0D!/3'!`B)!"3H!='__\G#58GE5E.#[$#'1>P`
M````QP0D`````.B8T/__BP")!"3HCLW__XD$).@&SO__Q@`!QP0D$-4$".A:
MT___B47P@WWP`'07BT7P#[8`/#%U#8M%\(/``0^V`(3`=`7H<MK__\<$)```
M``#H1M#__XL`B00DZ#S-___'1"0,"P```,=$)`@!````QT0D!([6!`B)!"3H
MW,S__XE%V(-]V``/A#\!``"+1=B+0`R+0!B)1=S'1>@!````Z<L```"+7>B#
MZP''!"0`````Z.7/__^+`(D$).C;S/__B<+'1"0,`````(E<)`B+1=R)1"0$
MB10DZ#[.__^)1>"#?>``#X23````BT7@BP"+0`@E``0``(7`=`V+1>"+`(M`
M#(E%R.LZBT7@BQC'!"0`````Z(+/__^+`(D$).AXS/__QT0D#`(```#'1"0(
M`````(E<)`2)!"3HO,___XE%R(M%Z,'@`HG"H>Q4!0B-!`*+`(M5R(E4)`2)
M!"3H6,___X7`=1:#1>P!@T7H`:'H5`4(.47H#XPG____H>A4!0B#Z`$[1>QU
M0<=%Z`$```#K+L<$)`````#H_,[__XL`B00DZ/++__^)PHM%W(E$)`2)%"3H
MD<O__XE%Y(-%Z`&AZ%0%"#E%Z'S(QP0D`````.C$SO__BP")!"3HNLO__\=$
M)`P%````QT0D"`$```#'1"0$D]8$"(D$).A:R___B478@WW8`'1PBT78BT`,
MBQC'!"0`````Z'W.__^+`(D$).ASR___QT0D")76!`B)7"0$B00DZ#_+__^+
M1=B+0`R+`(M`""4``$``A<!T*HM%V(M`#(L8QP0D`````.@WSO__BP")!"3H
M+<O__XE<)`2)!"3H`<W__\<$)`````#H%<[__XL`B00DZ`O+___'1"0,!0``
M`,=$)`@!````QT0D!)K6!`B)!"3HJ\K__XE%V(-]V``/A(8```#'1?0`````
MQP0D^M0$".BNT/__B47T@WWT`'0UBT78BT`,BQC'!"0`````Z*[-__^+`(D$
M).BDRO__B<*+1?2)1"0(B5PD!(D4).AORO__ZS6A[%0%"(LPBT78BT`,BQC'
M!"0`````Z'+-__^+`(D$).AHRO__B70D"(E<)`2)!"3HEL[__\<$)`````#H
M3,W__XL`B00DZ$+*__^)!"3HNLK__\8``,<$)`````#H*\W__XL`B00DZ"'*
M__^)!"3H2<W__\<``````,<$)/'4!`CHZL___Z/D5`4(H>14!0B%P`^%%@$`
M`*'L5`4(B00DZ,SP__^CY%0%"*'L5`4(B47,BT78BT`,BP"+0`@E``0``(7`
M=!"+1=B+0`R+`(M`#(E%T.L]BT78BT`,BQC'!"0`````Z*/,__^+`(D$).B9
MR?__QT0D#`(```#'1"0(`````(E<)`2)!"3HW<S__XE%T(M5S(E4)`2+1=")
M!"3HB,K__XE%Z(M%V(M`#(L`BT`()0`$``"%P'00BT78BT`,BP"+0`R)1=3K
M/8M%V(M`#(L8QP0D`````.@MS/__BP")!"3H(\G__\=$)`P"````QT0D"```
M``")7"0$B00DZ&?,__^)1=2A[%0%"(L0BT7HB40D#(M%U(E$)`B)5"0$QP0D
MG-8$".@OR___H>14!0C'1"0$[0$``(D$).B:Q___B47H@WWH`'0T@WWH$70N
M@WWH_W0HBQ7D5`4(H>Q4!0B+"(M%Z(E$)`R)5"0(B4PD!,<$),S6!`CHW<K_
M_X/$0%M>7<-5B>6#[!C'!"0`````Z'3+__^+`(D$).AJR/__B00DZ%K,___'
M!"0`````Z%;+__^+`(D$).A,R/__QT0D%`````#'1"00&M8$",=$)`P:U@0(
MQT0D"*G*!`C'1"0$&M<$"(D$).C\R/__R<.-3"0$@^3P_W'\58GE4U&#[#")
M3>2+1>2#P`B)1"0(BT7D@\`$B40D!(M%Y(D$).C&RO__QT0D"%R7!`C'1"0$
M7)<$",<$)"R9!`CHC@(``,<$)`````#H[L?__P^V`(3`=4WHTL?__Z/@5`4(
MH>!4!0B%P'4,QP0D`0```.C8RO__H>!4!0B)!"3H>\C__\<$)`````#H?\K_
M_XL`B00DZ'7'__^)!"3HS<G__\8``,<$)`````#H7LK__XL`B00DZ%3'__^)
M!"3H7,K__XG"#[8"@\@"B`+'!"0`````Z#;*__^+`(D$).@LQ___B00DZ#3*
M__^)P@^V`H/(`8@"BU7DBP*#P`6Z`````%)0WRPDC60D"-GNWL'=!3C7!`C9
MR=KIW^">#Y?`@_`!A,!U#,<$)*1$!0CH+<G__XM-Y(L!P>`"@\`4B00DZ#K)
M__^C[%0%"(L5[%0%"(M=Y(M#!(L`B0*A[%0%"(/`!,<`+]<$"*'L5`4(@\`(
MQP!@UP0(QP7H5`4(`P```*'H5`4(P>`"B<*A[%0%"(T$`L<`,M<$"*'H5`4(
M@\`!H^A4!0C'1?0!````ZR^A[%0%"(U0_*'H5`4(`T7TP>`"C0P"BT7TP>`"
MB<*+7>2+0P2-!`*+`(D!@T7T`8M5Y(L".47T?,>A[%0%"(U(_(M=Y(L3H>A4
M!0B-!`+!X`*-!`''``````"+#>Q4!0B+1>2+$*'H5`4(C00"@^@!BQ7@5`4(
MQT0D$`````")3"0,B40D",=$)`36SP0(B10DZ+O$__^)1?"#??``=1"AX%0%
M"(D$).A5Q?__B47PH>!4!0B)!"3H5<?__\<$)"#5!`CH?,O__X7`=3"AY%0%
M"(7`=1''!"3QU`0(Z&/+__^CY%0%"*'D5`4(A<!T#:'D5`4(B00DZ(+T__^A
MX%0%"(D$).@XQ/__Z//%__^+1?"#Q#!96UV-8?S#D)"0D)"0D)"0D%6)Y5/H
M,@```('#`W```(/L$(N#1`$``(E$)`R+11")1"0(BT4,B40D!(M%"(D$).B'
MQ/__@\006UW#BQPDPY!5B>5=PXUT)@"-O"<`````58GE5U93Z.#___^!P[%O
M``"#[`SH,\/__XV[\/[__XV#\/[__RG'P?\"A?]T)#'VBT40B40D"(M%#(E$
M)`2+10B)!"3_E+/P_O__@\8!.?=UWH/$#%M>7UW#D)"0D)"058GE4X/L#(M%
M#.A\____@<--;P``QP0D`P```(E$)`B+10B)1"0$Z*##__^#Q`Q;7<.0D)"0
MD)"0D)"0D)"0D%6)Y5.#[`R+10SH//___X'##6\``,<$)`,```")1"0(BT4(
MB40D!.B`Q/__@\0,6UW#D)"0D)"0D)"0D)"0D)!5B>53@^P$H1Q"!0B#^/]T
M$C';_]"+@QA"!0B#ZP2#^/]U\(/$!%M=PY"0D%6)Y5.#[`3H`````%N!PZ1N
M``#H;,?__UE;R<,```````````,````!``(`<&5R;'AS:2YC`$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@`O<')O8R]S96QF+V5X90`O`#H`97AE`"]P
M<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`N`"5S)7,E<P!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!0
M05)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'
M`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q````7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("```$Q$7TQ)0E)!4EE?4$%42`!,24)0051(
M`$Q)0E)!4EE?4$%42`!0051(`$193$1?3$E"4D%265]0051(``!#.EQ414U0
M`"]T;7``5$U01$E2`%1%35!$25(`5$5-4`!435``55-%4@!54T523D%-10!P
M87(M`%-94U1%30`E<R5S)7,E<P`E<R5S8V%C:&4M)7,E<P`E,#)X`"5S)7-T
M96UP+25U)7,`+BX`)7,O)7,`05)'5@`8`'!E<FP`,``E<SH@97AE8W5T:6]N
M(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@`E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`M(&%B;W)T:6YG('=I=&@@)6DN"@!);G1E<FYA;',Z.E!!4CHZ0D]/5``M
M90`M+0```````(#____/07!A<BYP;```````````````````````````````
M````(R$O=7-R+V)I;B]P97)L"@IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@
M<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I
M;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.0H*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@
M1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]
M*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T
M96UP.PH@("`@<FUD:7(@)'1O<&1I<CL*"B`@("!I9B`H+60@)'!A<E]T96UP
M*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@
M=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I
M8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI
M;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B
M;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD
M"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@
M;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"@H@("`@("`@(&UY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@
M)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC
M;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@
M("`@("`C($)E8V%U<V4@=&AE('!A<E]T96UP(&1I<F5C=&]R>2!I<R!G;VEN
M9R!T;R!B92!D96QE=&5D(&EN(&$*("`@("`@("`C(&)A8VMG<F]U;F0@<')O
M8V5S<RP@=&AE('!A<F5N="!P<F]C97-S(&ED(&UA>2!B92!R975S960@8F5F
M;W)E('1H90H@("`@("`@(",@8F%C:V=R;W5N9"!P<F]C97-S(&-O;7!L971E
M<RX@(%1O(&5N<W5R92!T:&%T('1H92!T96UP;W)A<GD*("`@("`@("`C(&1I
M<F5C=&]R>2!D;V5S(&YO="!G970@<F5U<V5D('=H:6QE(&ET(&ES(&)E:6YG
M(&1E;&5T960L('1R>2!T;PH@("`@("`@(",@<F5N86UE(&ET('1O(&$@;F%M
M92!T:&%T(&ES(')E;&%T960@=&\@=&AE('1E;7!O<F%R>2!S8W)I<'0@9FEL
M92X*"B`@("`@("`@;7D@)'1M<&YA;64@/2`H1FEL93HZ4W!E8RT^<W!L:71P
M871H*"1T;7`M/F9I;&5N86UE*2E;,ET[(",@9FEL96YA;64*("`@("`@("`D
M=&UP;F%M92`]?B!S+UPN6UXN72HD+RYD:7(O.PH@("`@("`@(&UY("1N97=$
M:7(@/2!&:6QE.CI3<&5C+3YC871P871H*`H@("`@("`@("`@("`H1FEL93HZ
M4W!E8RT^<W!L:71P871H*"1P87)?=&5M<"DI6S`N+C%=+"`D=&UP;F%M92D[
M"B`@("`@("`@:68@*')E;F%M92`D<&%R7W1E;7`L("1N97=$:7(I('L*("`@
M("`@("`@("`@;W5T<R@B4F5N86UE9"`D<&%R7W1E;7`@=&\@)&YE=T1I<B(I
M.PH@("`@("`@("`@("`D<&%R7W1E;7`@/2`D;F5W1&ER.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1>3R`]?B!M+W=I;C,R+VDI('L*("`@("`@("`@("`@
M<')I;G0@)'1M<"`B"CIL;V]P"G)M9&ER("]Q("]S(%PB)'!A<E]T96UP7"(*
M:68@97AI<W0@7"(D<&%R7W1E;7!<(B!G;W1O(&QO;W`*<FUD:7(@7"(D=&]P
M9&ER7"(*<FT@7"(B("X@)'1M<"T^9FEL96YA;64@+B`B7"(*(CL*("`@("`@
M("`@("`@8VQO<V4@)'1M<#L*("`@("`@("`@("`@;7D@)'!R;V,["B`@("`@
M("`@("`@(%=I;C,R.CI0<F]C97-S.CI#<F5A=&4H"B`@("`@("`@("`@("`@
M("`D<')O8RP@)$5.5GM#3TU34$5#?2P*("`@("`@("`@("`@("`@("(D14Y6
M>T-/35-014-]("]C(%PB(B`N("1T;7`M/F9I;&5N86UE("X@(EPB(#YN=6P@
M,CYN=6P@(BP*("`@("`@("`@("`@("`@(#$L($Y/4DU!3%]04DE/4DE465]#
M3$%34RP@(BXB"B`@("`@("`@("`@("D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G=H:6QE(%L@+60@)R1P
M87)?=&5M<"<@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"F1O;F4*<FUD
M:7(@)R1T;W!D:7(G"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@
M("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@
M("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*("`@("`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("`@("`@
M<WES=&5M*"1C;60I.PH@("`@("`@('T*("`@("`@("!O=71S*'%Q*%-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<"DI.PH@
M("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"![
M"@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?
M,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D
M14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I
M.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R
M("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY0
M05)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY
M("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@
M+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC
M($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D
M(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@
M("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K
M(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@
M(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D
M92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@
M("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@
M(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB
M+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A
M7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A
M8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I
M<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@
M(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U
M9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;
M82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F
M:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@
M("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R
M:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@
M("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L
M;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@
M("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U
M;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I
M;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@
M("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@
M("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@
M("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O
M=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@
M("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA
M;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@
M;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L
M92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D[
M"B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@
M("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@
M("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F
M:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.
M0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@
M("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I
M;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I
M.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@
M("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@
M)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@
M*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[
M8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@
M("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D
M9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D
M;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@
M("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB
M.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F
M:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C
M97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z
M.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M
M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@
M(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65]
M(&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E
M<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@
M("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@
M("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV
M95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@
M("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C
M('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@
M("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R
M9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*)'%U:65T(#T@,"!U
M;FQE<W,@)$5.5GM005)?1$5"54=].PH*(R!$;VXG="!S=V%L;&]W(&%R9W5M
M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO
M<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H
M"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?
M<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG
M;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("!M>2!`
M861D7W1O7VEN8SL*("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@
M("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@<'5S:"!`861D
M7W1O7VEN8RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M32<I('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("!]"B`@
M("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("!U;G-H:69T
M($!P87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E
M<2`G3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("1B=6YD;&4@
M/2`G<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I
M('L*("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("1Q=6EE="`]
M(#$["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@
M("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#
M86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@
M("`@("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("!I9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@9&5L971E
M("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN:71?:6YC*"D["B`@
M("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`F>R)0
M05(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@
M("`@97AI=#L*("`@("`@("!]"B`@("!]"@H@("`@=6YS:&EF="!`24Y#+"!`
M861D7W1O7VEN8SL*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O
M<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII
M9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG
M?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q
M=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*
M("`@('T*"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z
M:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY
M("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D
M(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@
M)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R
M(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@
M)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A
M;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I
M9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A
M<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@
M("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!
M4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U
M="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@
M("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P
M-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@
M)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F
M.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R
M(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L
M(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?
M7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T
M(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E
M="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@
M("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O
M(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U
M;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!
M4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PH@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@<F5Q=6ER95]M;V1U
M;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@
M;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@
M("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@
M("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@
M("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@
M?2!`24Y#.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L:6U](&5Q("=<7"<I
M('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@;7D@)69I;&5S.PH@
M("`@("`@("]>7SPH+BLI)"\@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E
M.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@
M("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M"B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D[
M"@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@
M("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@
M("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@
M>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D
M,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N
M*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F
M(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H
M(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N
M86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@
M("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@
M*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H
M<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@
M("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#
M86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E
M*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@
M("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@
M("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O+RH@
M9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@/7X@
M<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@("`@
M("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R+G!M
M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E
M;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N
M86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@
M("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@
M('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!0
M05(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL
M94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ
M4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E
M=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B
M*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D
M8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M
M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@
M("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N
M86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R
M:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B
M7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L
M("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R
M92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA
M;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET
M(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@
M("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@
M("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@
M("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@
M("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@
M("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@
M("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^
M8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@
M("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q
M*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D
M97-T7VYA;64I.PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T
M:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@
M("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N
M86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@
M("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U
M:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[
M)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@
M("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E
M<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER
M92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R
M<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E
M($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&
M:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@
M0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)
M3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U
M:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER
M92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(&5V86P@>R!R97%U:7)E
M($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@
M>R!R97%U:7)E(%=I;C,R.CI0<F]C97-S('T["B`@("!E=F%L('L@<F5Q=6ER
M92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C
M;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PIS=6(@7W-E=%]P87)?
M=&5M<"!["B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@
M("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@
M("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N
M("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@
M("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW
M:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@
M("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD
M=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@
M("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L
M("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@
M,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@
M("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@
M("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@
M)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O
M9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@
M("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E
M<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE
M*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB
M("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$[
M"B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP
M+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T
M;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@
M;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E
M;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F
M:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C
M<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@
M=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S
M:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@
M("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE
M*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N
M86UE*3L*?0H*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@*"1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M
M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@
M("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A
M8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@
M("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@
M("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D[
M"B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@
M(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@
M("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2![
M"B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@
M("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%
M04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@
M)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F
M:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<
M;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I
M9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO
M;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE
M('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE
M("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*
M?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3<*"E]?
M14Y$7U\*``````#_____`````/____\```````````$````!`````0```+("
M```!````O0(```$```#'`@```0````4#```!````)P0```P```"\E@0(#0``
M`'S4!`@$````2($$"/7^_V^<A`0(!0```!B-!`@&````^(4$"`H```"^!0``
M"P```!`````5``````````,````L0P4(`@```&@"```4````$0```!<```!4
ME`0($0```#R4!`@2````&````!,````(````_O__;[R3!`C___]O`@```/#_
M_V_6D@0(````````````````````````````````````````````````````
M`````````````````#!"!0@```````````*7!`@2EP0((I<$"#*7!`A"EP0(
M4I<$"&*7!`AREP0(@I<$")*7!`BBEP0(LI<$",*7!`C2EP0(XI<$"/*7!`@"
MF`0($I@$""*8!`@RF`0(0I@$"%*8!`ABF`0(<I@$"(*8!`B2F`0(HI@$"+*8
M!`C"F`0(TI@$".*8!`CRF`0(`ID$"!*9!`@BF00(,ID$"$*9!`A2F00(8ID$
M"'*9!`B"F00(DID$"**9!`BRF00(PID$"-*9!`CBF00(\ID$"`*:!`@2F@0(
M(IH$"#*:!`A"F@0(4IH$"&*:!`ARF@0(@IH$")*:!`BBF@0(LIH$",*:!`C2
MF@0(XIH$"/*:!`@"FP0($IL$""*;!`@RFP0(0IL$"%*;!`ABFP0(<IL$"(*;
M!`B2FP0(HIL$"+*;!`C"FP0(```````````H0@4(W=0$"-_4!`C_____0-<$
M"+=:````1T-#.B`H1TY5*2`T+C(N,R`H1&5B:6%N(#0N,BXS+3,I``!'0T,Z
M("A'3E4I(#0N,BXS("A$96)I86X@-"XR+C,M,RD``$=#0SH@*$=.52D@-"XR
M+C,@*$1E8FEA;B`T+C(N,RTT*0``1T-#.B`H1TY5*2`T+C(N,R`H1&5B:6%N
M(#0N,BXS+30I``!'0T,Z("A'3E4I(#0N,BXS("A$96)I86X@-"XR+C,M-"D`
M`$=#0SH@*$=.52D@-"XR+C,@*$1E8FEA;B`T+C(N,RTS*0``1T-#.B`H1TY5
M*2`T+C(N,R`H1&5B:6%N(#0N,BXS+3,I``!'0T,Z("A'3E4I(#0N,BXS("A$
M96)I86X@-"XR+C,M,RD``$=#0SH@*$=.52D@-"XR+C,@*$1E8FEA;B`T+C(N
M,RTS*0``1T-#.B`H1TY5*2`T+C(N,R`H1&5B:6%N(#0N,BXS+30I``!'0T,Z
M("A'3E4I(#0N,BXS("A$96)I86X@-"XR+C,M,RD``"YS:'-T<G1A8@`N:6YT
M97)P`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+F-T;W)S`"YD
M=&]R<P`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M````"P````$````"````%($$"!0!```3```````````````!`````````!,`
M```'`````@```"B!!`@H`0``(```````````````!``````````E````!0``
M``(```!(@00(2`$``%0#```%``````````0````$````(0```/;__V\"````
MG(0$")P$``!<`0``!0`````````$````!````"L````+`````@```/B%!`CX
M!0``(`<```8````!````!````!`````S`````P````(````8C00(&`T``+X%
M``````````````$`````````.P```/___V\"````UI($"-82``#D````!0``
M```````"`````@```$@```#^__]O`@```+R3!`B\$P``@`````8````"````
M!`````````!7````"0````(````\E`0(/!0``!@````%``````````0````(
M````8`````D````"````5)0$"%04``!H`@``!0````P````$````"````&D`
M```!````!@```+R6!`B\%@``,```````````````!`````````!D`````0``
M``8```#LE@0([!8``.`$``````````````0````$````;P````$````&````
MT)L$"-`;``"L.``````````````0`````````'4````!````!@```'S4!`A\
M5```'```````````````!`````````![`````0````(```"@U`0(H%0``'A=
M`````````````"``````````@P````$````"````&#(%"!BR```$````````
M```````$`````````(T````!`````P```!Q"!0@<L@``"```````````````
M!`````````"4`````0````,````D0@4()+(```@```````````````0`````
M````FP````$````#````+$(%""RR```$```````````````$`````````*``
M```&`````P```#!"!0@PL@``^`````8`````````!`````@```"I`````0``
M``,````H0P4(*+,```0```````````````0````$````K@````$````#````
M+$,%""RS``!``0`````````````$````!````+<````!`````P```&Q$!0AL
MM```(```````````````!`````````"]````"`````,```"@1`4(C+0``%`0
M`````````````"``````````P@````$``````````````(RT``"!`0``````
M```````!``````````$````#```````````````-M@``RP``````````````
(`0``````````
